============================
Cinder Configuration Options
============================

The following is a sample Cinder configuration for adaptation and use. It is
auto-generated from Cinder when this documentation is built, so if you are
having issues with an option, please compare your version of Cinder with the
version of this documentation.

The sample configuration can also be viewed in
`file form <_static/cinder.conf.sample>`_.

.. literalinclude:: _static/cinder.conf.sample
